aind\_behavior\_curriculum.curriculum.Metrics
=============================================

.. currentmodule:: aind_behavior_curriculum.curriculum

.. autoclass:: Metrics
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Metrics.__init__
      ~Metrics.construct
      ~Metrics.copy
      ~Metrics.dict
      ~Metrics.from_orm
      ~Metrics.json
      ~Metrics.model_construct
      ~Metrics.model_copy
      ~Metrics.model_dump
      ~Metrics.model_dump_json
      ~Metrics.model_json_schema
      ~Metrics.model_parametrized_name
      ~Metrics.model_post_init
      ~Metrics.model_rebuild
      ~Metrics.model_validate
      ~Metrics.model_validate_json
      ~Metrics.model_validate_strings
      ~Metrics.parse_file
      ~Metrics.parse_obj
      ~Metrics.parse_raw
      ~Metrics.schema
      ~Metrics.schema_json
      ~Metrics.update_forward_refs
      ~Metrics.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Metrics.model_computed_fields
      ~Metrics.model_config
      ~Metrics.model_extra
      ~Metrics.model_fields
      ~Metrics.model_fields_set
   
   